# Edges


## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**iterable** | [**List[Node]**](Node.md) |  | 

## Example

```python
from openapi_client.models.edges import Edges

# TODO update the JSON string below
json = "{}"
# create an instance of Edges from a JSON string
edges_instance = Edges.from_json(json)
# print the JSON string representation of the object
print Edges.to_json()

# convert the object into a dict
edges_dict = edges_instance.to_dict()
# create an instance of Edges from a dict
edges_form_dict = edges.from_dict(edges_dict)
```
[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


